@@ -33,7 +33,7 @@ API Reference
 .. automodulesumm:: sphinx_toolbox.more_autodoc.overloads
 	:autosummary-sections: Functions
 
-"""  # noqa D400
+"""
 #
 #  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
@@ -141,7 +141,7 @@ class OverloadMixin(_OverloadMixinBase):
 
 		# Size varies depending on docutils config
 		output.indent_type = ' '
-		output.indent_size = self.env.app.config.docutils_tab_width  # type: ignore
+		output.indent_size = self.env.app.config.docutils_tab_width
 
 		if self.analyzer and '.'.join(self.objpath) in self.analyzer.overloads:
 
@@ -152,12 +152,20 @@ class OverloadMixin(_OverloadMixinBase):
 
 				for name, param in overload.parameters.items():
 					buf.append(f"**{name}**")
+
 					if param.annotation is not Parameter.empty:
 						buf.append(r"\: ")
 						buf.append(format_annotation(param.annotation))
+
 					if param.default is not Parameter.empty:
+						default = param.default
+
+						if hasattr(inspect, "DefaultValue") and isinstance(default, inspect.DefaultValue):
+							default = default.value
+
 						buf.append(" = ")
-						buf.append(param.default)
+						buf.append(default)
+
 					buf.append(r"\, ")
 
 				if buf[-2][-1] != '`':
