@@ -64,6 +64,7 @@ Functions for testing Sphinx extensions.
 
 # stdlib
 import copy
+import re
 import sys
 import tempfile
 from functools import partial
@@ -74,7 +75,12 @@ from typing import Any, Callable, Dict, List, NamedTuple, Optional, Set, Tuple,
 import pytest  # nodep
 import sphinx.application
 from bs4 import BeautifulSoup  # type: ignore
-from coincidence.regressions import check_file_output, check_file_regression  # nodep
+from coincidence.regressions import (  # nodep
+		AdvancedFileRegressionFixture,
+		check_file_output,
+		check_file_regression
+		)
+from docutils import __version_info__ as docutils_version
 from docutils import nodes
 from docutils.parsers.rst import Directive, roles
 from docutils.transforms import Transform
@@ -113,6 +119,8 @@ __all__ = [
 		"check_asset_copy",
 		"HTMLRegressionFixture",
 		"html_regression",
+		"LaTeXRegressionFixture",
+		"latex_regression",
 		]
 
 
@@ -578,9 +586,9 @@ def run_setup(setup_func: _setup_func_type) -> RunSetupOutput:  # , buildername:
 
 	app.add_domain(PythonDomain)
 
+	_additional_nodes = copy.copy(docutils.additional_nodes)
 	try:
-		_additional_nodes = copy.copy(docutils.additional_nodes)
-		docutils.additional_nodes = set()
+		sphinx.util.docutils.additional_nodes = set()
 
 		with docutils.docutils_namespace():
 			setup_ret = setup_func(app)  # type: ignore
@@ -679,6 +687,7 @@ class HTMLRegressionFixture(FileRegressionFixture):
 		*,
 		extension: str = ".html",
 		jinja2: bool = False,
+		jinja2_namespace: Optional[Dict[str, Any]] = None,
 		**kwargs
 		):
 		r"""
@@ -686,16 +695,20 @@ class HTMLRegressionFixture(FileRegressionFixture):
 
 		:param page: The page to test.
 		:param jinja2: Whether to render the reference file as a jinja2 template.
+		:param jinja2_namespace: If ``jinja2`` is :py:obj:`True`,
+			a mapping of variable names to values to make available in the jinja2 template.
 		:param \*\*kwargs: Additional keyword arguments passed to
 			:meth:`pytest_regressions.file_regression.FileRegressionFixture.check`.
 
 		.. versionchanged:: 2.14.0  Added the ``jinja2`` keyword argument.
+		.. versionchanged:: 2.17.0  Added the ``jinja2_namespace`` keyword argument.
 
 		When ``jinja2`` is :py:obj:`True`, the reference file will be rendered as a jinja2 template.
 		The template is passed the following variables:
 
 		* ``sphinx_version`` -- the Sphinx version number, as a tuple of integers.
 		* ``python_version`` -- the Python version number, in the form returned by :data:`sys.version_info`.
+		* ``docutils_version`` -- the docutils version number, as a tuple of integers (*New in version 2.16.0*).
 
 		**Example usage**
 
@@ -742,6 +755,8 @@ class HTMLRegressionFixture(FileRegressionFixture):
 						template.render(
 								sphinx_version=sphinx.version_info,
 								python_version=sys.version_info,
+								docutils_version=docutils_version,
+								**jinja2_namespace or {},
 								)
 						)
 
@@ -800,3 +815,119 @@ def check_asset_copy(
 			filename = tmp_pathplus / filename
 
 			check_file_output(filename, file_regression, extension=f"_{filename.stem}{filename.suffix}")
+
+
+_latex_date_re = re.compile(r"\\date{.*}")
+
+
+class LaTeXRegressionFixture(AdvancedFileRegressionFixture):
+	"""
+	Subclass of :class:`coincidence.regressions.AdvancedFileRegressionFixture` for checking LaTeX files.
+
+	.. versionadded:: 2.17.0
+	"""
+
+	def check(  # type: ignore
+		self,
+		contents: Union[str, StringList],
+		*,
+		extension: str = ".html",
+		jinja2: bool = False,
+		jinja2_namespace: Optional[Dict[str, Any]] = None,
+		**kwargs
+		):
+		r"""
+		Check a LaTeX file generated by Sphinx for regressions,
+		using `pytest-regressions <https://pypi.org/project/pytest-regressions/>`__
+
+		:param contents:
+		:param jinja2: Whether to render the reference file as a jinja2 template.
+		:param jinja2_namespace: If ``jinja2`` is :py:obj:`True`,
+			a mapping of variable names to values to make available in the jinja2 template.
+		:param \*\*kwargs: Additional keyword arguments passed to
+			:meth:`pytest_regressions.file_regression.FileRegressionFixture.check`.
+
+		When ``jinja2`` is :py:obj:`True`, the reference file will be rendered as a jinja2 template.
+		The template is passed the following variables:
+
+		* ``sphinx_version`` -- the Sphinx version number, as a tuple of integers.
+		* ``python_version`` -- the Python version number, in the form returned by :data:`sys.version_info`.
+		* ``docutils_version`` -- the docutils version number, as a tuple of integers (*New in version 2.16.0*).
+
+		.. note::
+
+			Unlike standard HTML jinja2 templates,
+			this class expects the use of ``<`` and ``>`` rather than ``{`` and ``}``.
+
+			For example::
+
+				<% if foo %>
+				<# This should only happen on Tuesdays #>
+				<< foo.upper() >>
+				<% endif %>
+
+		**Example usage**
+
+		.. code-block:: python
+
+			@pytest.mark.sphinx("latex")
+			def test_latex_output(app: Sphinx, latex_regression: LaTeXRegressionFixture):
+				app.build()
+				output_file = app.outdir / "python.tex"
+				latex_regression.check(output_file.read_text())
+
+		"""  # noqa: D400
+
+		__tracebackhide__ = True
+
+		if jinja2:
+
+			def check_fn(obtained_filename: PathPlus, expected_filename: PathLike):
+				expected_filename = PathPlus(expected_filename)
+
+				template = Template(
+						expected_filename.read_text(),
+						block_start_string="<%",
+						block_end_string="%>",
+						variable_start_string="<<",
+						variable_end_string=">>",
+						comment_start_string="<#",
+						comment_end_string="#>",
+						)
+
+				expected_filename.write_text(
+						template.render(
+								sphinx_version=sphinx.version_info,
+								python_version=sys.version_info,
+								docutils_version=docutils_version,
+								**jinja2_namespace or {},
+								)
+						)
+
+				return check_text_files(obtained_filename, expected_filename, encoding="UTF-8")
+
+		else:
+			check_fn = partial(check_text_files, encoding="UTF-8")
+
+		new_contents = _latex_date_re.sub(
+				r"\\date{Mar 11, 2021}",
+				str(contents).replace("\\sphinxAtStartPar\n", ''),
+				)
+		new_contents = new_contents.replace("%% let collapsible ", "%% let collapsable ")  # changed in Sphinx 4.2
+
+		return super().check(
+				new_contents,
+				extension=".tex",
+				check_fn=check_fn,
+				)
+
+
+@pytest.fixture()
+def latex_regression(datadir, original_datadir, request) -> LaTeXRegressionFixture:
+	"""
+	Returns a :class:`~.LaTeXRegressionFixture` scoped to the test function.
+
+	.. versionadded:: 2.17.0
+	"""
+
+	return LaTeXRegressionFixture(datadir, original_datadir, request)
